@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -44,7 +44,8 @@ ProxyConn::ProxyConn()
     : m_iSsl(0)
     , m_flag(0)
 {
-    strcpy(m_extraHeader, "Accept-Encoding: gzip\r\nX-Forwarded-For: ");
+    lstrncpy(m_extraHeader, "Accept-Encoding: gzip\r\nX-Forwarded-For: ",
+             sizeof(m_extraHeader));
     memset(&m_iTotalPending, 0,
            ((char *)(&m_pChunkIS + 1)) - (char *)&m_iTotalPending);
 }
@@ -483,7 +484,7 @@ int ProxyConn::readvSsl(const struct iovec *vector,
 }
 
 
-int ProxyConn::readv(struct iovec *vector, size_t count)
+int ProxyConn::readv(struct iovec *vector, int count)
 {
     int len;
     int total = 0;
@@ -938,7 +939,7 @@ void ProxyConn::dump()
             "Response header: %d, total: %d bytes received in %ld seconds,"
             "Total processing time: %ld.",
             getState(), getEvents(), m_iReqHeaderSize,
-            (long long)m_iReqBodySize, (long long)m_iReqTotalSent, 
+            (long long)m_iReqBodySize, (long long)m_iReqTotalSent,
             m_iRespHeaderRecv, m_iRespRecv,
             (m_lReqSentTime) ? time(NULL) - m_lReqSentTime : 0,
             time(NULL) - m_lReqBeginTime);
