@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -76,8 +76,14 @@ int ByteRange::check(off_t entityLen)
 
 HttpRange::HttpRange(off_t entityLen)
     : m_lEntityLen(entityLen)
+    , m_iCurRange(0)
+    , m_pPartHeaderEnd(NULL)
+    , m_pCurHeaderPos(NULL)
 {
     ::memset(m_boundary, 0, sizeof(m_boundary));
+    m_iCurRange = 0;
+    m_pPartHeaderEnd = 0x00;
+    m_pCurHeaderPos = 0x00;
 }
 
 
@@ -169,7 +175,7 @@ int HttpRange::parse(const char *pRange, ls_xpool_t *pool)
     int state = 0;
     ByteRange range(-1, -1);
     off_t lValue = 0;
-    off_t total = 0;
+    //off_t total = 0;
     while (state != 6)
     {
         switch (ch)
@@ -259,9 +265,9 @@ int HttpRange::parse(const char *pRange, ls_xpool_t *pool)
                     state = 6;
                     break;
                 }
-                total += range.getLen();
-                if (total > m_lEntityLen)
-                    return SC_200;
+                //total += range.getLen();
+                //if (total > m_lEntityLen)
+                //    return SC_200;
                 range.setBegin(-1);
                 range.setEnd(-1);
                 state = 0;
