@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -242,9 +242,12 @@ int buildMoov(HttpSession *pSession)
         {
             LS_DBG_L(pReq->getLogSession(), "is_mem, buf_size=%u, remaining=%d",
                      moov_data->mem.buf_size, moov_data->remaining_bytes);
-            pSession->appendDynBody((char *)moov_data->mem.buffer,
-                                    moov_data->mem.buf_size);
-            free(moov_data->mem.buffer);
+            if (moov_data->mem.buffer)
+            {
+                pSession->appendDynBody((char *)moov_data->mem.buffer,
+                                        moov_data->mem.buf_size);
+                free(moov_data->mem.buffer);
+            }
             moov_data->mem.buffer = NULL;
         }
         else
@@ -526,6 +529,7 @@ int StaticFileHandler::process(HttpSession *pSession,
              compressed, mode, ret);
     FileCacheDataEx *pECache = pInfo->getECache();
 
+
     if (!ret)
     {
         //Check the bypass modsec flag set or not
@@ -592,25 +596,13 @@ int StaticFileHandler::process(HttpSession *pSession,
         //ret = pSession->flush();
         ret = pSession->endResponse(1);
     }
-
-    if (code == SC_200 && !pSession->getFlag(HSF_STX_FILE_CACHE_READY))
+    if (ret == 0 && code == SC_200 && !pSession->getFlag(HSF_STX_FILE_CACHE_READY))
     {
         pCache->setBypassModsec(1);
-        if (ret == 0)
-        {
-            HttpVHost *host = (HttpVHost *)pSession->getReq()->getVHost();
-            host->addUrlStaticFileMatch(pInfo->getFileData(),
-                                        pReq->getOrgReqURL(), pReq->getOrgReqURLLen());
-            LS_DBG_L( pSession->getLogSession(), "[static file cache] create cache." );
-        }
-        else
-        {
-            /**
-             * Serving not done, add flag to save to static file cache when 
-             * response is done
-             */
-            pSession->setFlag(HSF_SAVE_STX_FILE_CACHE);
-        }
+        HttpVHost *host = (HttpVHost *)pSession->getReq()->getVHost();
+        host->addUrlStaticFileMatch(pInfo->getFileData(),
+                                    pReq->getOrgReqURL(), pReq->getOrgReqURLLen());
+        LS_DBG_L( pSession->getLogSession(), "[static file cache] create cache." );
     }
     return ret;
 
