@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -29,6 +29,9 @@
 DirHashCacheEntry::DirHashCacheEntry()
     : CacheEntry()
     , m_lastCheck(-1)
+    , m_lastMod(0)
+    , m_lSize(0)
+    , m_inode(0)
 {
 }
 
@@ -172,7 +175,7 @@ int DirHashCacheEntry::saveRespHeaders(HttpRespHeaders *pHeader)
         return LS_FAIL;
     pKey = pHeader->getHeader(HttpRespHeaders::H_LAST_MODIFIED, &keyLen);
     if (pKey)
-        getHeader().m_tmLastMod = DateTime::parseHttpTime(pKey);
+        getHeader().m_tmLastMod = DateTime::parseHttpTime(pKey, keyLen);
     /*
      * FIXME: need to locate etag header location
         pHeader->getHeader( HttpRespHeaders::H_ETAG, &pKey, &keyLen);
