@@ -1,6 +1,20 @@
-/*
- *
- */
+/*****************************************************************************
+*    Open LiteSpeed is an open source HTTP server.                           *
+*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
+*                                                                            *
+*    This program is free software: you can redistribute it and/or modify    *
+*    it under the terms of the GNU General Public License as published by    *
+*    the Free Software Foundation, either version 3 of the License, or       *
+*    (at your option) any later version.                                     *
+*                                                                            *
+*    This program is distributed in the hope that it will be useful,         *
+*    but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the            *
+*    GNU General Public License for more details.                            *
+*                                                                            *
+*    You should have received a copy of the GNU General Public License       *
+*    along with this program. If not, see http://www.gnu.org/licenses/.      *
+*****************************************************************************/
 
 #include "quicstream.h"
 #include "quiclog.h"
@@ -244,6 +258,7 @@ int QuicStream::checkReadRet(int ret)
             tobeClosed();
             LS_DBG_L(this, "read error: %s\n", strerror(errno));
         }
+        break;
     default:
         bytesRecv(ret);
         setActiveTime(DateTime::s_curTime);
@@ -278,14 +293,14 @@ int QuicStream::read(char *pBuf, int size)
 int QuicStream::push(ls_str_t *pUrl, ls_str_t *pHost,
                    ls_strpair_t *pExtraHeaders)
 {
+    if (!m_pStream)
+        return -1;
+
     lsquic_conn_t *pConn = lsquic_stream_conn(m_pStream);
     lsquic_http_headers_t headers;
     ls_strpair_t *p = pExtraHeaders;
     int pushed;
 
-    if (!m_pStream)
-        return -1;
-
     while(p && p->key.ptr != NULL)
     {
         ++p;
