@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -210,7 +210,7 @@ void H2Stream:: continueWrite()
 
 int H2Stream::onTimer()
 {
-    if (getState() == HIOS_CONNECTED && getHandler())
+    if (getState() == HIOS_CONNECTED)
         return getHandler()->onTimerEx();
     return 0;
 }
@@ -596,5 +596,3 @@ int H2Stream::push(ls_str_t *pUrl, ls_str_t *pHost,
                                   pExtraHeaders);
 }
 
-
-
